@@ -1,7 +1,7 @@
 # Copyright (c) Kuba Szczodrzyński 2022-05-09.
 
 import os
-from os.path import join
+from os.path import isfile, join
 
 import click
 from click import echo
@@ -253,16 +253,16 @@ def variant(
         writer.generate(board=board)
 
         out_h = join(output, f"{board.id}.h")
-        out_cpp = join(output, f"{board.id}.cpp")
+        out_c = join(output, f"{board.id}.c")
         if subdir:
             out_h = join(output, board.id, f"variant.h")
-            out_cpp = join(output, board.id, f"variant.cpp")
+            out_c = join(output, board.id, f"variant.c")
 
-        echo(f"Saving to '{out_h}' and '{out_cpp}'...")
+        echo(f"Saving to '{out_h}' and '{out_c}'...")
         board_name = f"{board.id}.json"
         writer.save_h(out_h, board_name)
         if writer.pins:
-            writer.save_cpp(out_cpp, board_name)
+            writer.save_c(out_c, board_name)
 
 
 @cli.command()
@@ -284,6 +284,22 @@ def all(
     ctx.invoke(variant, boards=boards, output=output, subdir=subdir)
 
 
+@cli.command()
+@click.option("--no-docs", "-D", is_flag=True, help="Write variant files only")
+@click.pass_context
+def ltci(ctx, no_docs: bool):
+    """Generate board files for LibreTuya CI"""
+    if not isfile("families.json"):
+        print("Run this command in LT root directory")
+        exit(1)
+    boards = load_boards(["all"])
+
+    if not no_docs:
+        ctx.invoke(draw, boards=boards, output="boards/", subdir=True)
+        ctx.invoke(write, boards=boards, output="boards/", subdir=True)
+    ctx.invoke(variant, boards=boards, output="boards/variants/", subdir=False)
+
+
 @cli.group(name="list")
 def list_cmd():
     """List boards/templates/etc"""
@@ -351,3 +367,7 @@ def list_flash():
     echo("Available flash regions:")
     for region_name, description in core.flash.items():
         echo(f" - {region_name}: {description}")
+
+
+if __name__ == "__main__":
+    cli()
